#
# spec file for package pdfsam-basic
#
# Copyright (c) 2020 Linux Kamarada Project, Florianópolis, Brazil.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# https://docs.fedoraproject.org/en-US/packaging-guidelines/SourceURL/#_git_hosting_services


Name:           pdfsam-basic
Summary:        PDF Split And Merge Basic Edition (PDFsam Basic)
Version:        4.2.10
Release:        lp153.2.1
License:        AGPL-3.0
Group:          Productivity/Text/Utilities
URL:            https://www.pdfsam.org
Source0:        https://github.com/torakiki/pdfsam/releases/download/v%{version}/pdfsam-%{version}-linux.tar.gz
Source1:        https://raw.githubusercontent.com/torakiki/pdfsam/v%{version}/%{name}/src/deb/icon.svg
Source2:        https://raw.githubusercontent.com/torakiki/pdfsam/v%{version}/%{name}/src/deb/%{name}.desktop

BuildArch:      x86_64
BuildRequires:  fdupes
BuildRequires:  unzip
BuildRequires:  update-desktop-files

Requires:       java >= 11

Obsoletes:      pdfsam < %{version}
Provides:       pdfsam = %{version}


%description
Open source desktop application to split, merge, rotate, extract pages and mix PDF files.


%prep
%setup -n pdfsam-%{version}-linux
rm bin/pdfsam.bat
mv bin/pdfsam.sh bin/%{name}
# PDFsam Basic v4.x comes with a Java runtime, not needed if Java is installed
rm -rf runtime


%build


%install
mkdir -p %{buildroot}/opt/%{name}
mv ./* %{buildroot}/opt/%{name}/
mkdir -p %{buildroot}%{_bindir}
ln -s /opt/%{name}/bin/%{name} %{buildroot}%{_bindir}/pdfsam
install -Dm644 %{SOURCE1} %{buildroot}/opt/%{name}/
install -Dm644 %{SOURCE2} %{buildroot}/usr/share/applications/%{name}.desktop

find %{buildroot}/opt/%{name} -type d -exec chmod 755 {} ';'
find %{buildroot}/opt/%{name} -type f -exec chmod 644 {} ';'
chmod 755 %{buildroot}/opt/%{name}/bin/pdfsam-basic

desktop-file-edit --set-generic-name 'PDF Split And Merge' %{buildroot}%{_datadir}/applications/%{name}.desktop
desktop-file-edit --add-category=X-Red-Hat-Base %{buildroot}%{_datadir}/applications/%{name}.desktop
desktop-file-edit --add-category=X-SuSE-Core-Office %{buildroot}%{_datadir}/applications/%{name}.desktop
# Same Categories as LibreOffice (/usr/share/applications/startcenter.desktop)

%fdupes -s %{buildroot}/opt/pdfsam-basic/


%files
%{_bindir}/pdfsam
/opt/pdfsam-basic
%license /opt/pdfsam-basic/LICENSE.txt
%{_datadir}/applications/%{name}.desktop


%changelog
* Wed Dec 22 2021 Antonio Vinicius Menezes Medeiros <linuxkamarada@gmail.com> - 4.2.10
- Update to version 4.2.10
  * Upgraded PDF Engine
  * Updated translations
  * Upgraded Logback to version 1.2.9 fixing https://jira.qos.ch/browse/LOGBACK-1591
* Sun Oct 17 2021 Antonio Vinicius Menezes Medeiros <linuxkamarada@gmail.com> - 4.2.7
- Update to version 4.2.7
  * Upgraded PDF Engine with fixes
* Wed Aug  5 2020 Antonio Vinicius Menezes Medeiros <linuxkamarada@gmail.com> - 4.1.4
- Update to version 4.1.4
  * Upgraded PDF engine (Sejda) and few other dependencies
  * Updated translations
  * Fixed an issue when adding a footer in the Merge tool
* Wed Jul  1 2020 Antonio Vinicius Menezes Medeiros <linuxkamarada@gmail.com> - 4.1.3
- Update to version 4.1.3
  * Upgraded Java to version 11.0.7
  * Upgraded Sejda
  * Improved move up in selection table to show the above row when moving rows up
* Sun Apr 12 2020 Antonio Vinicius Menezes Medeiros <linuxkamarada@gmail.com> - 4.1.2
- Update to version 4.1.2
  * Upgraded SAMBox, Sejda and JavaFX
  * Fixed few issues with AcroForms merging
  * Fixed few minor issues
* Mon Feb 10 2020 Antonio Vinicius Menezes Medeiros <linuxkamarada@gmail.com> - 4.1.1
- Update to PDF Split and Merge Basic Edition v4.1.1
  * Prefix fields now save and restore the latest used value
  * Fixed split tasks to handle a case with PDF not conforming the PDF spec
  * Added a notification in case one of the input PDF files gets deleted before the task is executed
  * Fixed the bookmarks handling in case of input PDF file not conforming the PDF spec created with wkhtmltopdf
  * Fixed handling of a non breaking white space 0xA0 when found in bookmarks and the [BOOKMARK_NAME] is used as prefix
  * Upgraded PDF engine (Sejda) to latest version (4.0.1)
  * Upgraded AdoptOpenJDK to latest version (11.0.6)
  * Upgraded translations
* Tue Oct 22 2019 Antonio Vinicius Menezes Medeiros <linuxkamarada@gmail.com> - 4.0.5
- Update to PDF Split and Merge Basic Edition v4.0.5
  * Upgraded PDF engine (Sejda) to latest version (3.2.85)
  * Upgraded AdoptOpenJDK to latest version (11.0.5)
  * Upgraded translations
  * Fixed an issue that was preventing PDFsam to start on some Windows machines #357 and #367
* Wed Sep  4 2019 Antonio Vinicius Menezes Medeiros <linuxkamarada@gmail.com>
- Update to version 4.0.4
* Tue Jun  4 2019 Antonio Vinicius Menezes Medeiros <linuxkamarada@gmail.com>
- Version 4.0.3
* Tue May  7 2019 Antonio Vinicius Menezes Medeiros <linuxkamarada@gmail.com>
- Removed built-in Java runtime, not needed as Java is required
* Tue May  7 2019 Antonio Vinicius Menezes Medeiros <linuxkamarada@gmail.com>
- Same Categories as LibreOffice
* Sun May  5 2019 Antonio Vinicius Menezes Medeiros <linuxkamarada@gmail.com>
- desktop-file-edit instead of %%suse_update_desktop_file, which is deprecated (https://lists.opensuse.org/opensuse-packaging/2011-12/msg00177.html)
* Sun May  5 2019 Antonio Vinicius Menezes Medeiros <linuxkamarada@gmail.com>
- Upgrade path renaming pdfsam to pdfsam-basic
* Sun May  5 2019 Antonio Vinicius Menezes Medeiros <linuxkamarada@gmail.com>
- Initial package with v4.0.1
